package xmlchecker;

import xmlchecker.XMLTreeNode;

import java.net.URI;
import java.net.URISyntaxException;

/**
  Abstrakte Elternklasse fr XML-Prfung
*/
public abstract class XMLChecker{
  private boolean namespaceAware;
  private boolean validating;
  private boolean usingSchema;
  private boolean creatingXMLTree;

/**
  Bercksichtigung von Namensrumen bei der Prfung
  @param   flag   <code>true</code>: Namensrume bercksichtigen
*/
  public void setNamespaceAware(boolean flag){
    this.namespaceAware = flag;
  }
/**
  Bercksichtigung von Namensrumen bei der Prfung
  @return  <code>true</code>: Namensrume werden bercksichtigt
*/
  public boolean isNamespaceAware(){
    return this.namespaceAware;
  }

/**
  Gltigkeitsprfung
  @param   flag   <code>true</code>: auf Gltigkeit prfen
*/
  public void setValidating(boolean flag){
    this.validating = flag;
  }
/**
  Gltigkeitsprfung
  @return  <code>true</code>: auf Gltigkeit wird geprft
*/
  public boolean isValidating(){
    return this.validating;
  }

/**
  Verweis auf ein XML-Schema bei Gltigkeitsprfung verwenden
  @param   flag   <code>true</code>: Verweise auf Schema verwenden
*/
  public void setUsingSchema(boolean flag){
    this.usingSchema = flag;
  }
/**
  Verweis auf ein XML-Schema bei Gltigkeitsprfung verwenden
  @return  <code>true</code>: Verweise auf Schema werden verwendet
*/
  public boolean isUsingSchema(){
    return this.usingSchema;
  }

/**
  XML-Baum bei Prfung erzeugen
  @param   flag   <code>true</code>: XML-Baum erzeugen
  @see     xmlchecker.XMLChecker#getTreeRoot()
*/
  public void setCreatingXMLTree(boolean flag){
    this.creatingXMLTree = flag;
  }
/**
  XML-Baum bei Prfung erzeugen
  @return  <code>true</code>: XML-Baum wird erzeugt
*/
  public boolean isCreatingXMLTree(){
    return this.creatingXMLTree;
  }

/**
  XML-Dokument prfen
  @param   docuri   URI des zu prfenden XML-Dokumentes
*/
  public abstract void check(String docuri);

/**
  der bei Prfung erstellte Wurzelknoten des XML-Baums
  @return  der Wurzelknoten
  @see     xmlchecker.XMLChecker#setCreatingXMLTree(boolean)
*/
  public abstract XMLTreeNode getTreeRoot();
/**
  die bei Prfung erstellten Meldungen
  @return   die Meldungen
*/
  public abstract String getMessages();
}